@@ -5,6 +5,8 @@ from typing import Optional, Union
 import sqlmodel as sqm
 from appdirs import AppDirs
 from cloudpathlib import CloudPath, GSClient, S3Client
+from cloudpathlib.exceptions import OverwriteNewerLocalError
+from lamin_logger import logger
 
 DIRS = AppDirs("lamindb", "laminlabs")
 
@@ -47,12 +49,25 @@ class Storage:
 
     def cloud_to_local(self, filepath: Union[Path, CloudPath]) -> Path:
         """Local (cache) filepath from filepath."""
-        if self.settings.cloud_storage:
-            filepath = filepath.fspath  # type: ignore  # mypy misses CloudPath
-        Path(filepath).parent.mkdir(
+        try:
+            # the following will auto-update the local cache if the cloud file is newer
+            # if both have the same age, it will keep it as is
+            if self.settings.cloud_storage:
+                local_filepath = CloudPath(filepath).fspath
+            else:
+                local_filepath = Path(filepath)
+        except OverwriteNewerLocalError:
+            local_filepath = self.cloud_to_local_no_update(filepath)  # type: ignore
+            logger.warning(
+                f"Local file ({local_filepath}) for cloud path ({filepath}) is newer on disk than in cloud.\n"  # noqa
+                "It seems you manually updated the database locally and didn't push changes to the cloud.\n"  # noqa
+                "This can lead to data loss if somebody else modified the cloud file in"
+                " the meantime."
+            )
+        Path(local_filepath).parent.mkdir(
             parents=True, exist_ok=True
         )  # this should not happen here but is currently needed
-        return filepath
+        return local_filepath
 
     # conversion to Path via cloud_to_local() would trigger download
     # of remote file to cache if there already is one
@@ -71,10 +86,10 @@ class Storage:
 
 class instance_description:
     storage_dir = """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""  # noqa
-    storage_region = """Cloud storage region for s3 and gcp"""
+    storage_region = """Cloud storage region for s3 and Google Cloud."""
     _dbconfig = """Either "sqlite" or "instance_name, postgres_url"."""
     name = """Instance name."""
-    schema_modules = """Comma-separated string of schema modules."""
+    schema_modules = """Comma-separated string of schema modules. None if not set."""
 
 
 def instance_from_storage(storage):
@@ -85,14 +100,14 @@ def instance_from_storage(storage):
 class InstanceSettings:
     """Instance settings written during setup."""
 
-    storage_dir: Union[CloudPath, Path] = None
+    storage_dir: Union[CloudPath, Path] = None  # None is just for init, can't be None
     """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""
     storage_region: Optional[str] = None
-    """Cloud storage region for s3 and gcp."""
+    """Cloud storage region for s3 and Google Cloud."""
     _dbconfig: str = "sqlite"
     """Either "sqlite" or "instance_name, postgres_url"."""
-    schema_modules: str = None  # type: ignore
-    """Comma-separated string of schema modules."""
+    schema_modules: Optional[str] = None  # type: ignore
+    """Comma-separated string of schema modules. None if not set."""
 
     @property
     def cloud_storage(self) -> bool:
