@@ -2,13 +2,12 @@ from pathlib import Path
 from typing import Union
 
 import lnschema_core
-import sqlmodel as sqm
 from cloudpathlib import CloudPath
 from lamin_logger import logger
-from sqlmodel import SQLModel
 
-from ._db import insert, insert_if_not_exists
+from ._db import insert_if_not_exists
 from ._docs import doc_args
+from ._migrate import check_migrate
 from ._settings_instance import InstanceSettings
 from ._settings_instance import instance_description as description
 from ._settings_load import (
@@ -19,24 +18,10 @@ from ._settings_load import (
 )
 from ._settings_save import save_instance_settings
 from ._settings_store import settings_dir
+from ._setup_schema import setup_schema
 from ._setup_storage import get_storage_region
 
 
-def configure_schema_wetlab(schema_modules):
-    def _no_biosample_techsample():
-        file_loc = lnschema_core.__file__.replace("core", "wetlab")
-        with open(file_loc, "r") as f:
-            content = f.read()
-        with open(file_loc, "w") as f:
-            content = content.replace(
-                '_tables = ["biosample", "techsample"]', "_tables = []"
-            )
-            f.write(content)
-
-    if any([i in schema_modules for i in {"retro", "swarm"}]):
-        _no_biosample_techsample()
-
-
 def update_db(isettings, usettings):
     insert_if_not_exists.user(usettings.email, usettings.id, usettings.handle)
 
@@ -51,29 +36,14 @@ def setup_instance_db():
     - Sign-up and/or log-in.
     """
     isettings = load_or_create_instance_settings()
-    user_settings = load_or_create_user_settings()
+    usettings = load_or_create_user_settings()
     if isettings.storage_dir is None:
         logger.warning("Instance is not configured. Call `lndb init` or `lndb load`.")
         return None
-    schema_modules = isettings.schema_modules
 
     if isettings._sqlite_file.exists():
         logger.info(f"Using instance: {isettings._sqlite_file}")
-
-        with sqm.Session(isettings.db_engine()) as session:
-            version_table = session.exec(sqm.select(lnschema_core.version_yvzi)).all()
-
-        versions = [row.v for row in version_table]
-
-        current_version = lnschema_core.__version__
-
-        if current_version not in versions:
-            logger.error(
-                f"Your database does not seem up-to-date with installed core schema module v{current_version}.\n"  # noqa
-                f"If you already migrated, run `lndb_setup._db.insert.version_yvzi({current_version}, db.settings.user.id)`\n"  # noqa
-                f"If not, migrate to core schema version {current_version} or install {versions}."  # noqa
-            )
-            return None
+        check_migrate(usettings=usettings, isettings=isettings)
     else:
         if isettings.cloud_storage and isettings._sqlite_file_local.exists():
             logger.error(
@@ -83,47 +53,18 @@ def setup_instance_db():
                 " location."
             )
             return None
-
-        msg = "Loading schema modules: core"
-
-        if schema_modules is not None and "bionty" in schema_modules:
-            import lnschema_bionty  # noqa
-
-            msg += ", bionty"
-        if schema_modules is not None and "wetlab" in schema_modules:
-            configure_schema_wetlab(schema_modules)
-
-            import lnschema_wetlab  # noqa
-
-            msg += ", wetlab"
-        if schema_modules is not None and "bfx" in schema_modules:
-            import lnbfx.schema  # noqa
-
-            msg += ", bfx"
-
-        if schema_modules is not None and "retro" in schema_modules:
-            import lnschema_retro  # noqa
-
-            msg += ", retro"
-        if schema_modules is not None and "swarm" in schema_modules:
-            import maren.schema  # noqa
-
-            msg += ", swarm"
-        logger.info(f"{msg}.")
-        SQLModel.metadata.create_all(isettings.db_engine())
-        isettings._update_cloud_sqlite_file()
-        insert.version_yvzi(lnschema_core.__version__, user_settings.id)
+        setup_schema(isettings, usettings)
         logger.info(
             f"Created instance {isettings.name} with core schema"
             f" v{lnschema_core.__version__}: {isettings._sqlite_file}"
         )
 
-    update_db(isettings, user_settings)
+    update_db(isettings, usettings)
 
 
 def load(instance_name: str):
     """Load existing instance."""
-    user_settings = load_or_create_user_settings()
+    usettings = load_or_create_user_settings()
     isettings = load_instance_settings(settings_dir / f"instance-{instance_name}.env")
     assert isettings.name is not None
     save_instance_settings(isettings)
@@ -132,7 +73,11 @@ def load(instance_name: str):
 
     settings._instance_settings = None
 
-    update_db(isettings, user_settings)
+    message = check_migrate(usettings=usettings, isettings=isettings)
+    if message == "migrate-failed":
+        return message
+    update_db(isettings, usettings)
+    return message
 
 
 @doc_args(
@@ -153,8 +98,8 @@ def init(
         dbconfig: {}
         schema: {}
     """
-    user_settings = load_or_create_user_settings()
-    if user_settings.id is None:
+    usettings = load_or_create_user_settings()
+    if usettings.id is None:
         logger.error("Login: lndb login user")
         return "need-to-login-first"
 
@@ -180,6 +125,8 @@ def init(
         if len(validated_schema) == 0:
             raise RuntimeError(f"Unknown schema modules. Only know {known_modules}.")
         instance_settings.schema_modules = ", ".join(validated_schema)
+    else:
+        instance_settings.schema_modules = None
 
     save_instance_settings(instance_settings)
 
